@@ -83,7 +83,7 @@ class NetcashOrder(models.Model):
     gateway = models.ForeignKey(NetcashGateway, null=True, blank=True)
     request_ip = models.IPAddressField(null=True, blank=True)
     debug_info = models.CharField(max_length=255, null=True, blank=True)
-    suspicious = models.NullBooleanField(default=None)
+    trusted = models.NullBooleanField(default=None)
 
     def save(self, *args, **kwargs):
         self.updated_at = datetime.now()
