@@ -55,7 +55,9 @@ class NetcashTest(TestCase):
            'Reference': reference,
            'RETC': '123',
            'Reason': '',
-           'Amount': '100'
+           'Amount': '100',
+           'm_4': 'extra value 1',
+           'm_6': 'extra value 3',
         })
 
         self.assertEqual(response.status_code, 200)
@@ -64,6 +66,9 @@ class NetcashTest(TestCase):
         self.assertEqual(order.TransactionAccepted, True)
         self.assertEqual(order.Amount, 100)
         self.assertEqual(order.RETC, '123')
+        self.assertEqual(order.Extra1, 'extra value 1')
+        self.assertEqual(order.Extra2, '')
+        self.assertEqual(order.Extra3, 'extra value 3')
         self.assertEqual(order.gateway, self.gateway)
         self.assertEqual(order.request_ip, '127.0.0.1')
         self.assertEqual(order.trusted, True)
